@@ -389,6 +389,7 @@ public:
 		CALL_RINGING,
 		CALL_DISCONNECT,
 		CALL_CLEARED,
+		CALL_PROCEEDING,
 		RESTART_FAILED,
 		RELEASE_FAILED,
 
@@ -688,7 +689,7 @@ public:
 	 * @param timeslots to allocate.
 	 * @param pointer to server shell.
 	 */	
-	static void allocate(timeslot_t timeslots, ScriptCommand *server = NULL);
+	static void allocate(timeslot_t timeslots, ScriptCommand *pointer = NULL);
 
 	/**
 	 * Wait for live flag...
@@ -720,13 +721,13 @@ public:
 	 * @param service level or NULL to clear.
 	 * @return true if set.
 	 */
-	static bool service(const char *svc);
+	static bool service(const char *service);
 
 	/**
 	 * Returns a session pointer for a server timeslot.  Each
 	 * server timeslot can map to a single session object.
 	 *
-	 * @param server timeslot number.
+	 * @param timeslot number in server.
 	 * @return session object or NULL if timeslot empty/invalid.
 	 */
 	static BayonneSession *getSession(timeslot_t timeslot);
@@ -736,7 +737,7 @@ public:
 	 * be for a transaction id, a call id, or other unique identifiers
 	 * which can be mapped into a single timeslot.
 	 *
-	 * @param string session identifier.
+	 * @param id session identifier string.
 	 * @return session object or NULL if not found.
 	 */
 	static BayonneSession *getSid(const char *id);
@@ -745,7 +746,7 @@ public:
 	 * Returns a server timeslot number for a string identifier.
 	 *
 	 * @return timeslot number or invalid value.
-	 * @param string identifier for a session.
+	 * @param id for a session.
 	 * @see #getSid
 	 */
 	static timeslot_t toTimeslot(const char *id);
@@ -790,7 +791,7 @@ public:
 	 * @param dtmf digit as ascii
 	 * @return dtmf digit number.
 	 */
-	static int getDigit(char dig);
+	static int getDigit(char dtmf);
 
 	/**
 	 * Convert a dtmf digit number into it's ascii code.
@@ -802,12 +803,12 @@ public:
 
 	/**
 	 * A function to support pattern matching and templates for digit
-	 * strings.  This is used for digit @xxx:... entries and the route
+	 * strings.  This is used for digit \@xxx:... entries and the route
 	 * command.
 	 *
 	 * @param digits to use.
-	 * @param digit pattern to match against.
-	 * @param accept partial match.
+	 * @param match digit pattern to match against.
+	 * @param partial accept match if true.
 	 * @return true if digits match to pattern.
 	 */
 	static bool matchDigits(const char *digits, const char *match, bool partial = false);
@@ -823,14 +824,14 @@ public:
 	 * Release a script image in use.  If no active calls are using it
 	 * and it's no longer the top active image, purge from memory.
 	 *
-	 * @param script image from useImage.
+	 * @param image to compiled script from useImage.
 	 */
-	static void endImage(ScriptImage *img);
+	static void endImage(ScriptImage *image);
 
 	/**
 	 * Load a plugin module.
 	 *
-	 * @param id of plugin.
+	 * @param path id of plugin.
 	 * @return true if successful.
 	 */
 	static bool loadPlugin(const char *path);
@@ -838,7 +839,7 @@ public:
         /**
          * Load a monitoring/management module.
          *
-         * @param id of plugin.
+         * @param path id of plugin.
          * @return true if successful.
          */
         static bool loadMonitor(const char *path);  
@@ -846,7 +847,7 @@ public:
 	/**
 	 * Load a bgm/audio processing module for continues audio.
 	 *
-	 * @param id of plugin.
+	 * @param path id of plugin.
 	 * @return true if successful.
 	 */
 	static bool loadAudio(const char *path);
@@ -880,7 +881,7 @@ public:
 	 *
 	 * @param iso name of language/locale.
 	 */
-	BayonneTranslator(const char *id);
+	BayonneTranslator(const char *iso);
 
 	/**
 	 * Find a translator for a given name/location.
@@ -912,134 +913,135 @@ public:
 	 * @param iso module name to load.
 	 * @return true if successful.
 	 */
-	static BayonneTranslator *loadTranslator(const char *name);
+	static BayonneTranslator *loadTranslator(const char *iso);
 
 	/**
 	 * Translate a simple set of digits to spoken speech.
 	 *
-	 * @param timeslot session to save list of prompts.
-	 * @param current count of prompts used.
+	 * @param session to save list of prompts.
+	 * @param count of current prompts used.
 	 * @param string to be processed.
 	 * @return new count of prompts used.
 	 */
-	virtual unsigned digits(BayonneSession *s, unsigned count, const char *cp);
+	virtual unsigned digits(BayonneSession *sessiob, unsigned count, const char *string);
 
         /**
          * Spell out the string as individual letters.
          *
-         * @param timeslot session to save list of prompts.
-         * @param current count of prompts used.
+         * @param session to save list of prompts.
+         * @param count of current prompts used.
          * @param string to be processed.
          * @return new count of prompts used.
          */
-	virtual unsigned spell(BayonneSession *s, unsigned count, const char *cp);
+	virtual unsigned spell(BayonneSession *session, unsigned count, const char *string);
 
         /**
          * Translate an ordinal number (xxnth) to prompts.
          *
-         * @param timeslot session to save list of prompts.
-         * @param current count of prompts used.
+         * @param session to save list of prompts.
+         * @param count of current prompts used.
          * @param string to be processed.
          * @return new count of prompts used.
          */
-	virtual unsigned sayorder(BayonneSession *s, unsigned count, const char *cp);
+	virtual unsigned sayorder(BayonneSession *session, unsigned count, const char *string);
 
         /**
          * Translate a number to spoken speech.
          *
-         * @param timeslot session to save list of prompts.
-         * @param current count of prompts used.
+         * @param session to save list of prompts.
+         * @param count of current prompts used.
          * @param string to be processed.
          * @return new count of prompts used.
          */
-	virtual unsigned number(BayonneSession *s, unsigned count, const char *cp);
+	virtual unsigned number(BayonneSession *session, unsigned count, const char *string);
 
 	/**
 	 * Translate generic numbers to spoken speech.  This is the one
 	 * used by the &number rule.
 	 *
-	 * @param timeslot session to save list of prompts.
-	 * @param current count of prompts used.
+	 * @param session to save list of prompts.
+	 * @param count of current prompts used.
 	 * @param string to be processed.
 	 * @return new count of prompts used.
 	 */
-	virtual unsigned saynumber(BayonneSession *s, unsigned count, const char *cp);
+	virtual unsigned saynumber(BayonneSession *session, unsigned count, const char *string);
 
         /**
          * Translate a counting number (integer) to spoken speech.
          *
-         * @param timeslot session to save list of prompts.
-         * @param current count of prompts used.
+         * @param session to save list of prompts.
+         * @param count of current prompts used.
          * @param string to be processed.
          * @return new count of prompts used.
          */
-	virtual unsigned saycount(BayonneSession *s, unsigned count, const char *cp);
+	virtual unsigned saycount(BayonneSession *session, unsigned count, const char *string);
 
         /**
          * Translate a string for time into speech.
          *
-         * @param timeslot session to save list of prompts.
-         * @param current count of prompts used.
+         * @param session to save list of prompts.
+         * @param count of current prompts used.
          * @param string to be processed.
          * @return new count of prompts used.
          */
-	virtual unsigned saytime(BayonneSession *s, unsigned count, const char *cp);
+	virtual unsigned saytime(BayonneSession *session, unsigned count, const char *string);
 
         /**
          * Translate a string with a date into the spoken weekday.
          *
-         * @param timeslot session to save list of prompts.
-         * @param current count of prompts used.
+         * @param session to save list of prompts.
+         * @param count of current prompts used.
          * @param string to be processed.
          * @return new count of prompts used.
          */
-	virtual unsigned weekday(BayonneSession *s, unsigned count, const char *cp);
+	virtual unsigned weekday(BayonneSession *session, unsigned count, const char *string);
 
         /**
          * Translate a string with a date into a spoken date.
          *
-         * @param timeslot session to save list of prompts.
-         * @param current count of prompts used.
+         * @param session to save list of prompts.
+         * @param count of current prompts used.
          * @param string to be processed.
          * @return new count of prompts used.
          */
-	virtual unsigned saydate(BayonneSession *s, unsigned count, const char *cp);
+	virtual unsigned saydate(BayonneSession *session, unsigned count, const char *string);
 
         /**
          * Translate a logical value and speak as yes/no.
          *
-         * @param timeslot session to save list of prompts.
-         * @param current count of prompts used.
+         * @param session to save list of prompts.
+         * @param count of current prompts used.
          * @param string to be processed.
          * @return new count of prompts used.
          */
-	virtual unsigned saybool(BayonneSession *s, unsigned count, const char *cp);
+	virtual unsigned saybool(BayonneSession *session, unsigned count, const char *string);
 
         /**
          * Translate and speak a phone number.
          *
-         * @param timeslot session to save list of prompts.
-         * @param current count of prompts used.
+         * @param session to save list of prompts.
+         * @param count of current prompts used.
          * @param string to be processed.
          * @return new count of prompts used.
          */
-	virtual unsigned phone(BayonneSession *s, unsigned count, const char *cp);
+	virtual unsigned phone(BayonneSession *session, unsigned count, const char *string);
 
         /**
          * Translate and speak a phone extension.
          *
-         * @param timeslot session to save list of prompts.
-         * @param current count of prompts used.
+         * @param session to save list of prompts.
+         * @param count of current prompts used.
          * @param string to be processed.
          * @return new count of prompts used.
          */
-	virtual unsigned extension(BayonneSession *s, unsigned count, const char *cp);
+	virtual unsigned extension(BayonneSession *session, unsigned count, const char *string);
 
         /**
          * Translation dispatch, processes script and invokes other methods.
          *
          * @return error message or NULL if okay
-	 * @param timeslot session to process a command from.
+	 * @param session to process a command from.
+	 * @param line of compiled script to process.
          */
 	virtual const char *speak(BayonneSession *session, Line *line = NULL);
 
@@ -1098,8 +1100,8 @@ public:
 	 * Convert a prompt identifier into a complete audio file pathname.
 	 *
 	 * @return pointer to fully qualified file path or NULL if invalid.
-	 * @param prompt requested.
-	 * @param true if request is for file write.
+	 * @param name of prompt requested.
+	 * @param write path required if true.
 	 */
         const char *getFilename(const char *name, bool write = false);
 
@@ -1113,18 +1115,18 @@ public:
 	 * Open a sequence of audio prompts for playback.	
 	 *
 	 * @param list of prompts to open.
-	 * @param playback mode for file processing of list.
+	 * @param mode for playback file processing of list.
 	 */
-	void play(const char **list, Mode m = modeRead);
+	void play(const char **list, Mode mode = modeRead);
 
 	/**
 	 * Open an audio prompt for recording.
 	 *
 	 * @param name of prompt to open.
-	 * @param mode, whether to create or use pre-existing recording.
+	 * @param mode whether to create or use pre-existing recording.
 	 * @param annotation to save in file if supported by format used.
 	 */
-	void record(const char *name, Mode m = modeCreate, const char *note = NULL);
+	void record(const char *name, Mode mode = modeCreate, const char *annotation = NULL);
 
 	/**
 	 * Check if a voice library is available.
@@ -1132,7 +1134,7 @@ public:
 	 * @return voice library id or NULL if invalid.
 	 * @param iso name of library to request.
 	 */
-	const char *getVoicelib(const char *cp);
+	const char *getVoicelib(const char *iso);
 
 	/**
 	 * Get audio codec used.
@@ -1261,12 +1263,12 @@ public:
 	/**
 	 * Create a driver instance.
 	 *
-	 * @param default keyword entries for config.
-	 * @param name of config key.
-	 * @param driver id string.
+	 * @param pairs of default keyword entries for config.
+	 * @param key name of config key.
+	 * @param id string of driver.
 	 * @param whether front load or use all timeslots.
 	 */
-	BayonneDriver(Keydata::Define *pairs, const char *cfg, const char *id, bool pri);
+	BayonneDriver(Keydata::Define *pairs, const char *key, const char *id, bool pri);
 
 	/**
 	 * Destroy driver instance.
@@ -1309,24 +1311,24 @@ public:
 	 * Process driver protocol specific proxy registration requests.
 	 *
 	 * @return error message if invalid request, NULL if ok.
-	 * @param script image being compiled.
+	 * @param image of script being compiled.
 	 * @param line record of "register" command.
 	 */
-        virtual const char *registerScript(ScriptImage *img, Line *line);
+        virtual const char *registerScript(ScriptImage *image, Line *line);
 
 	/**
 	 * Process driver specific assign requests.
 	 *
 	 * @return error message if invalid request, NULL if ok.
-	 * @param script image being compiled.
+	 * @param image of script being compiled.
 	 * @param line record of "assign" command.
 	 */
-	virtual const char *assignScript(ScriptImage *img, Line *line);
+	virtual const char *assignScript(ScriptImage *image, Line *line);
 
 	/**
 	 * Find and return driver object from id name.
 	 *
-	 * @param driver name.
+	 * @param id driver name.
 	 * @return associated driver node.
 	 */
 	static BayonneDriver *get(const char *id);
@@ -1334,8 +1336,7 @@ public:
 	/**
 	 * Load a bayonne driver into memory.
 	 *
-	 * @param prefix path to load.
-	 * @param driver name to load.
+	 * @param id driver name to load.
 	 * @return NULL or pointer to loaded driver.
 	 */
 	static BayonneDriver *loadDriver(const char *id);
@@ -1360,8 +1361,8 @@ public:
 	/**
 	 * Get list of driver names into string array.
 	 *
-	 * @param array to save in.
-	 * @param count of elements available.
+	 * @param items array to save in.
+	 * @param max count of elements available.
 	 * @return number of drivers.
 	 */
 	static unsigned BayonneDriver::list(char **items, unsigned max);
@@ -1510,7 +1511,7 @@ public:
 	/**
 	 * Get the nth span object associated with this driver.
 	 *
-	 * @param nth span to return.
+	 * @param id of nth span to return.
 	 * @return span object or NULL if past limit/no spans.
 	 */
 	BayonneSpan *getSpan(unsigned id);
@@ -1519,7 +1520,7 @@ public:
 	 * Get the session associated with the nth timeslot for this
 	 * driver.
 	 *
-	 * @param nth timeslot of driver.
+	 * @param id of nth timeslot of driver.
 	 * @return session object.
 	 */
 	BayonneSession *getTimeslot(timeslot_t id);
@@ -1559,7 +1560,7 @@ public:
 	/**
 	 * Set driver logging.
 	 *
-	 * @param stream to log driver.
+	 * @param output stream to log driver.
 	 */
 	inline void setLogging(std::ostream *output)
 		{logevents = output;};
@@ -1576,13 +1577,13 @@ public:
 	 * Deterime if a network destination is reachable through this
 	 * driver, and convert dialing string into network reference.
 	 *
-	 * @param network destination
-	 * @param dialing string
+	 * @param target network destination
+	 * @param dial string
 	 * @param output buffer
 	 * @param size of output buffer
 	 * @return true if reachable
 	 */
-	virtual bool getDestination(const char *target, const char *dial, char *buffer, size_t size);
+	virtual bool getDestination(const char *target, const char *dial, char *output, size_t size);
 
 	/**
 	 * Get available timeslots.
@@ -1623,12 +1624,12 @@ public:
 	 * @param driver associated with span.
 	 * @param timeslots this span covers.
 	 */
-	BayonneSpan(BayonneDriver *d, timeslot_t count);
+	BayonneSpan(BayonneDriver *driver, timeslot_t timeslots);
 
 	/**
 	 * Get a span by a global span id.
 	 *
-	 * @param numeric span id.
+	 * @param id of span.
 	 * @return span object associated with id.
 	 */
 	static BayonneSpan *get(unsigned id);
@@ -1636,7 +1637,7 @@ public:
 	/**
 	 * Get the session associated with the nth timeslot of the span.
 	 *
-	 * @param nth timeslot of span.
+	 * @param id of nth timeslot of span.
 	 * @return associated session object.
 	 */
 	BayonneSession *getTimeslot(timeslot_t id);
@@ -1646,7 +1647,7 @@ public:
 	 *
 	 * @param total span count.
 	 */
-	static void allocate(unsigned count = 0);
+	static void allocate(unsigned total = 0);
 
 	/**
 	 * Return total spans in use.
@@ -1883,9 +1884,9 @@ protected:
 	 *
 	 * @param string to write.
 	 */
-	void libWrite(const char *str);
+	void libWrite(const char *string);
 
-	void libClose(const char *str);
+	void libClose(const char *string);
 
 	bool isLibexec(const char *tsid);
 
@@ -1897,10 +1898,10 @@ public:
 	/**
 	 * Process interpreter session symbols.
 	 *
-	 * @param symbol being requested.
+	 * @param option symbol being requested.
 	 * @return NULL if not external, else value.
 	 */
-	const char *getExternal(const char *opt);
+	const char *getExternal(const char *option);
 
 	/**
 	 * Get event sequence id
@@ -1922,7 +1923,7 @@ protected:
 	/**
 	 * Return ccengine symbol page map.  Gives access to globals.
 	 *
-	 * @param table symbol id.
+	 * @param id table of symbols.
 	 * @return table map to use.
 	 */
 	ScriptSymbols *getSymbols(const char *id);
@@ -2036,11 +2037,11 @@ public:
 	/**
 	 * Create a new session
 	 *
-	 * @param bind to driver.
-	 * @param bind to timeslot.
-	 * @param bind to span, or NULL if no span associated.
+	 * @param driver to bind.
+	 * @param timeslot to bind.
+	 * @param span to bind, or NULL if no span associated.
 	 */
-	BayonneSession(BayonneDriver *d, timeslot_t timeslot, BayonneSpan *span = NULL);
+	BayonneSession(BayonneDriver *driver, timeslot_t timeslot, BayonneSpan *span = NULL);
 
 	/**
 	 * Destroy a session.
@@ -2077,7 +2078,7 @@ public:
 	 * Return time remaining until timer expires.  Commonly used for
 	 * msgport scheduling.
 	 *
-	 * @param time remaining in milliseconds.
+	 * @return time remaining in milliseconds.
 	 */
 	virtual timeout_t getRemaining(void) = 0;
 
@@ -2085,7 +2086,7 @@ public:
 	 * Start a timer on the session.  Used extensivily in state
 	 * handler code.
 	 *
-	 * @param start timer for specified milliseconds.
+	 * @param timer to start for specified milliseconds.
 	 */
 	virtual void startTimer(timeout_t timer) = 0;
 
@@ -2098,7 +2099,7 @@ public:
 	/**
 	 * Set the port hook state.  Mostly for analog devices.
 	 *
-	 * @param true to set offhook, false onhook.
+	 * @param state true to set offhook, false onhook.
 	 */
 	virtual void setOffhook(bool state);
 
@@ -2110,7 +2111,7 @@ public:
 	/**
 	 * Disconnect notify peer...
 	 *
-	 * @param event id to pass
+	 * @param reason event id to pass
 	 */
 	void part(event_t reason);
 
@@ -2161,7 +2162,7 @@ public:
 	 * Check script keywords for audio processing.
 	 *
 	 * @return NULL if ok, else error message.
-	 * @param true if for live, else for file processing.
+	 * @param live true if for live, else for file processing.
 	 */
 	const char *getAudio(bool live = true);
 
@@ -2239,8 +2240,8 @@ public:
 	 * @param signal to send to script engine.
 	 * @return true if signal claimed.
 	 */
-	inline bool signalScript(signal_t sig)
-		{return ScriptInterp::signal(sig);};
+	inline bool signalScript(signal_t signal)
+		{return ScriptInterp::signal(signal);};
 
 	/**
 	 * Post a peer audio frame into the driver.  The frame is assumed
@@ -2249,7 +2250,7 @@ public:
 	 * format.
 	 *
 	 * @return true if peer frame was posted.
-	 * @param audio frame to peer.
+	 * @param encoded audio frame to peer.
 	 */
 	virtual bool peerAudio(Audio::Encoded encoded);
 
@@ -2260,7 +2261,7 @@ public:
 	 *
 	 * @return true if set.
 	 * @param encoding format requested.
-	 * @param frame timing to use.
+	 * @param framing timer to use.
 	 */
 	virtual bool setPeering(Audio::Encoding encoding, timeout_t framing);
 
@@ -2299,7 +2300,7 @@ public:
 	 * @return true if throw caught.
 	 * @param event message.
 	 */
-	bool digitEvent(const char *evt);
+	bool digitEvent(const char *event);
 
 	inline bool stringEvent(const char *evt)
 		{return scriptEvent(evt);}
