@@ -130,6 +130,15 @@ Libexec::Libexec()
 	}
 }
 
+void Libexec::postSym(const char *id, const char *value)
+{
+	const char *sid = head.getLast("SESSION");
+	if(!sid)
+		return;
+
+	cout << sid << " POST " << id << " " << value << endl;
+}
+
 const char *Libexec::getArg(const char *id)
 {
 	return args.getLast(id);
