@@ -249,6 +249,12 @@ void BayonneSysexec::run(void)
 var:
 			s->sysVar(tsid, var, value, size);
 		}
+                else if(!stricmp(cmd, "post"))
+                {
+                        var = strtok_r(NULL, " \t\r\n", &tok); 
+                        value = strtok_r(NULL, " \t\r\n", &tok);
+                        s->sysPost(tsid, var, value);
+                } 
 		else if(!stricmp(cmd, "flush"))
 			s->sysFlush(tsid);
 		else if(!stricmp(cmd, "wait"))
@@ -411,8 +417,6 @@ void BayonneSysexec::allocate(const char *libexec, size_t bs, int pri, const cha
 	slog.level(Slog::levelInfo);
 
 	slog.info("libexec starting; path=%s", libpath);
-	if(err)
-		fprintf(stderr, "libexec starting; path=%s\n", libpath);
 
 	// !exec
 	argv[0] = "libexec.bin";
