@@ -19,7 +19,27 @@
 #include <cc++/process.h>
 #include <ccrtp/rtp.h>
 #undef	HAVE_CONFIG_H
-#include <eXosip/eXosip.h>
+#include <eXosip2/eXosip.h>
+
+#define BAD_REQ                 400
+#define UNAUTHORIZED    401
+#define FORBIDDEN               403
+#define NOT_FOUND               404
+#define NOT_ALLOWED             405
+#define NOT_ACCEPTABLE  406
+#define AUTH_REQUIRED   407
+#define REQ_TIMEOUT             408
+#define UNSUP_MEDIA_TYPE        415
+#define TEMP_UNAVAILABLE 480
+#define ADDR_INCOMPLETE 484
+#define BUSY_HERE               486
+#define REQ_TERMINATED  487
+#define NOT_ACCEPTABLE_HERE 488 // Not Acceptable Here
+// 5XX errors
+#define SERVICE_UNAVAILABLE     503
+// 6XX errors
+#define BUSY_EVERYWHERE 600
+#define DECLINE                 603
 
 namespace sipdriver {
 using namespace ost;
@@ -35,13 +55,15 @@ public:
 //	const char *route;
 	const char *hostid;
 	const char *portid;
-	const char *userid;
+	const char *userid, *localid;
 	const char *secret;
 	const char *type;
 	const char *realm;
 	const char *dtmf;
 	int regid;
 	bool active;
+
+	bool isActive(void);
 };
 	
 class Driver : public BayonneDriver, public Audio, public Thread
@@ -52,7 +74,7 @@ protected:
 
 	InetAddress sip_addr, rtp_addr;
 	tpport_t rtp_port, sip_port;
-	uint8 dtmf_payload, data_payload;
+	uint8 dtmf_negotiate, data_negotiate;
 	Info info;
 	bool registry;
 	bool exiting;
@@ -80,11 +102,10 @@ public:
 
 	Session *getCall(int callid);
 
-	bool getDestination(const char *target, const char *dial, char *buffer, size_t size);
+	void setAuthentication(Registry *reg);
+	bool getAuthentication(Session *s);
 
 	void run(void);
-	void refresh(void);
-	bool authenticate(Session *s);
 
 	inline Level getSilence(void)
 		{return silence;};
@@ -205,8 +226,6 @@ public:
 
 	tpport_t getLocalPort(void);
 
-	void sipAnswer(int code);
-
 	void sipHangup(void);
 
 	inline tpport_t getRemotePort(void)
