@@ -490,6 +490,12 @@ live:
 	keyoptions.setValue("prefix", keypaths.getLast("datafiles"));
 	keyserver.setValue("state", "live");
 
+#ifdef	SCRIPT_SERVER_PREFIX
+	Script::var_prefix = keypaths.getLast("datafiles");
+	Script::etc_prefix = keypaths.getLast("config");
+	Script::log_prefix = keypaths.getLast("logfiles");
+#endif
+
 	// only for live server...
 }
 
